@@ -3,7 +3,6 @@ from typing import Tuple, Union, List
 
 import numpy as np
 from pymatgen.core import Structure, Molecule
-
 from pymatgen.optimization.neighbors import find_points_in_spheres
 
 from featurebox.utils.predefined_typing import StructureOrMolecule
@@ -34,6 +33,7 @@ def get_radius_in_spheres(
     Get graph representations from structure within cutoff.
 
     Args:
+        pbc (tuple of bool): pbc
         structure (pymatgen Structure or molecule)
         cutoff (float): cutoff radius
         numerical_tol (float): numerical tolerance
@@ -70,7 +70,7 @@ def get_radius_in_spheres(
     # exclude_self = (center_indices != neighbor_indices) | (distances > numerical_tol)
 
     return center_indices[exclude_self], neighbor_indices[exclude_self], distances[exclude_self].reshape(-1, 1), \
-           distances[exclude_self], np.array(None)
+           distances[exclude_self], np.array(np.NaN)
 
 
 if __name__ == "__main__":
@@ -79,7 +79,6 @@ if __name__ == "__main__":
     structure = Structure.from_file("../../data/temp_test_structure/W2C.cif")
     tt.t
     get_points_ = get_radius_in_spheres(structure,
-                                        cutoff=5.0, pbc=True,
-                                        )
+                                        cutoff=5.0, )
     tt.t  #
     tt.p
